function Ks=kval(t,p)
% kval		- Finds the distribution coefficient for a set of compounds
% function Ks=kval(t,p)
% Argument List:
% Argument    Gives
%    t      temperature in the units given by Tdeg.
%             (must be a scalar.)
%    p      pressure in kPa (must be a scalar).
% The vector of ideal Ks=(y1/x1, y2/x2,...) is returned.
% Ex: start301b
%     Give the file name with property data for benzene and toluene
%    Tdeg='C'; 
%    kval(25,10)
Ks=vappr(t)/p;
